:mod:`neuronvisio.manager` -- Manage the map between vectors and sections
=========================================================================

   
.. automodule:: neuronvisio.manager

:class:`Manager`
----------------

.. autoclass:: Manager
   :members:

:class:`BaseRef`
----------------

.. autoclass:: BaseRef
    :members:

:class:`VecRef`
---------------

.. autoclass:: VecRef
   :members:
   
:class:`SynVecRef`
------------------

.. autoclass:: SynVecRef
   :members:
   



